@@ -28,9 +28,8 @@ sub cleanup()
 
 sub cb()
 {
-	my ($dummy,$payload) = @_;
+	my ($payload) = @_;
 	print "Perl callback called!\n";
-	print "dummy is $dummy\n" if $dummy;
 	if ($payload) {
 		print "len: " . $payload->get_length() . "\n";
 
@@ -47,28 +46,20 @@ sub cb()
 			print "TCP dst_port: $tcp_obj->{dest_port}\n";
 		}
 
-		$payload->set_verdict($nfqueue::NF_DROP);
+		$payload->set_verdict($nfqueue::NF_ACCEPT);
 	}
 }
 
 
 $q = new nfqueue::queue();
 
-print "open\n";
-$q->open();
-print "bind\n";
-$q->bind(AF_INET);
-
 $SIG{INT} = "cleanup";
 
-#print "set callback, wrong argument type (should fail)\n";
-#$q->set_callback("blah");
-
 print "setting callback\n";
 $q->set_callback(\&cb);
 
-print "creating queue\n";
-$q->create_queue(0);
+print "open\n";
+$q->fast_open(0, AF_INET);
 
 $q->set_queue_maxlen(5000);
 
